==> dokuwiki-2013.12.08.tgz: dokuwiki/inc/lang/lt/lang.php <==
<?php
/**
 * lithuanian language file
 *
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * @author Linas Valiukas <shirshegsm@gmail.com>
 * @author Edmondas Girkantas <eg@zemaitija.net>
 * @author Arūnas Vaitekūnas <aras@fan.lt>
 * @author audrius.klevas@gmail.com
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Redaguoti šį puslapį';
$lang['btn_source']            = 'Parodyti puslapio kodą';
$lang['btn_show']              = 'Parodyti puslapį';
$lang['btn_create']            = 'Sukurti šį puslapį';
$lang['btn_search']            = 'Paieška';
$lang['btn_save']              = 'Išsaugoti';
$lang['btn_preview']           = 'Peržiūra';
$lang['btn_top']               = 'Į viršų';
$lang['btn_newer']             = '<< naujesnė';
$lang['btn_older']             = 'senesnė >>';
$lang['btn_revs']              = 'Senos versijos';
$lang['btn_recent']            = 'Naujausi keitimai';
$lang['btn_upload']            = 'Atsiųsti bylą';
$lang['btn_cancel']            = 'Atšaukti';
$lang['btn_index']             = 'Indeksas';
$lang['btn_secedit']           = 'Redaguoti';
$lang['btn_login']             = 'Prisijungti';
$lang['btn_logout']            = 'Atsijungti';
$lang['btn_admin']             = 'Administracija';
$lang['btn_update']            = 'Atnaujinti';
$lang['btn_delete']            = 'Ištrinti';
$lang['btn_back']              = 'Atgal';
$lang['btn_backlink']          = 'Atgalinės nuorodos';
$lang['btn_backtomedia']       = 'Atgal į Mediabylos išsirinkimą';
$lang['btn_subscribe']         = 'Užsisakyti keitimų prenumeratą';
$lang['btn_profile']           = 'Atnaujinti profilį';
$lang['btn_reset']             = 'Atstata';
$lang['btn_draft']             = 'Redaguoti juodraštį';
$lang['btn_recover']           = 'Atkurti juodraštį';
$lang['btn_draftdel']          = 'Šalinti juodraštį';
$lang['btn_register']          = 'Registruotis';
$lang['loggedinas']            = 'Prisijungęs kaip';
$lang['user']                  = 'Vartotojo vardas';
$lang['pass']                  = 'Slaptažodis';
$lang['newpass']               = 'Naujas slaptažodis';
$lang['oldpass']               = 'Patvirtinti esamą slaptažodį';
$lang['passchk']               = 'dar kartą';
$lang['remember']              = 'Prisiminti mane';
$lang['fullname']              = 'Visas vardas';
$lang['email']                 = 'El. pašto adresas';
$lang['profile']               = 'Vartotojo profilis';
$lang['badlogin']              = 'Nurodėte blogą vartotojo vardą arba slaptažodį.';
$lang['minoredit']             = 'Nedidelis pataisymas';
$lang['draftdate']             = 'Juodraštis automatiškai išsaugotas';
$lang['nosecedit']             = 'Puslapis buvo kažkieno pataisytas, teksto dalies informacija tapo pasenusi, todėl pakrautas visas puslapis.';
$lang['regmissing']            = 'Turite užpildyti visus laukus.';
$lang['reguexists']            = 'Vartotojas su pasirinktu prisijungimo vardu jau egzistuoja.';
$lang['regsuccess']            = 'Vartotojas sukurtas, slaptažodis išsiųstas el. paštu.';
$lang['regsuccess2']           = 'Vartotojas sukurtas.';
$lang['regmailfail']           = 'Siunčiant slaptažodį el. paštu įvyko klaida - susisiekite su administracija!';
$lang['regbadmail']            = 'Nurodytas el. pašto adresas yra neteisingas - jei manote, kad tai klaida, susisiekite su administracija';
$lang['regbadpass']            = 'Įvesti slaptažodžiai nesutampa, bandykite dar kartą.';
$lang['regpwmail']             = 'Jūsų DokuWiki slaptažodis';
$lang['reghere']               = 'Dar neužsiregistravote? Padarykite tai dabar';
$lang['profna']                = 'Ši vikisvetainė neleidžia pakeisti profilio';
$lang['profnochange']          = 'Nėra pakeitimų, todėl nėra ką atlikti.';
$lang['profnoempty']           = 'Tuščias vardo arba el. pašto adreso laukas nėra leidžiamas.';
$lang['profchanged']           = 'Vartotojo profilis sėkmingai atnaujintas.';
$lang['pwdforget']             = 'Pamiršote slaptažodį? Gaukite naują';
$lang['resendna']              = 'Ši vikisvetainė neleidžia persiųsti slaptažodžių.';
$lang['resendpwdmissing']      = 'Jūs turite užpildyti visus laukus.';
$lang['resendpwdnouser']       = 'Tokio vartotojo nėra duomenų bazėje.';
$lang['resendpwdbadauth']      = 'Atsiprašome, bet šis tapatybės nustatymo kodas netinkamas. Įsitikinkite, kad panaudojote pilną patvirtinimo nuorodą.';
$lang['resendpwdconfirm']      = 'Patvirtinimo nuoroda išsiųsta el. paštu.';
$lang['resendpwdsuccess']      = 'Jūsų naujas slaptažodis buvo išsiųstas el. paštu.';
$lang['license']               = 'Jei nenurodyta kitaip, šio wiki turinys ginamas tokia licencija:';
$lang['licenseok']             = 'Pastaba: Redaguodami šį puslapį jūs sutinkate jog jūsų turinys atitinka licencijavima pagal šią licenciją';
$lang['txt_upload']            = 'Išsirinkite atsiunčiamą bylą';
$lang['txt_filename']          = 'Įveskite wikivardą (nebūtina)';
$lang['txt_overwrt']           = 'Perrašyti egzistuojančią bylą';
$lang['lockedby']              = 'Užrakintas vartotojo';
$lang['lockexpire']            = 'Užraktas bus nuimtas';
$lang['js']['willexpire']            = 'Šio puslapio redagavimo užrakto galiojimo laikas baigsis po minutės.\nNorėdami išvengti nesklandumų naudokite peržiūros mygtuką ir užraktas atsinaujins.';
$lang['js']['notsavedyet']     = 'Pakeitimai nebus išsaugoti.\nTikrai tęsti?';
$lang['rssfailed']             = 'Siunčiant šį feed\'ą įvyko klaida: ';
$lang['nothingfound']          = 'Paieškos rezultatų nėra.';
$lang['mediaselect']           = 'Mediabylos išsirinkimas';
$lang['fileupload']            = 'Mediabylos atsiuntimas';
$lang['uploadsucc']            = 'Atsiuntimas pavyko';
$lang['uploadfail']            = 'Atsiuntimas nepavyko. Blogi priėjimo leidimai??';
$lang['uploadwrong']           = 'Atsiuntimas atmestas. Bylos tipas neleistinas';
$lang['uploadexist']           = 'Tokia byla jau egzistuoja. Veiksmai atšaukti.';
$lang['uploadbadcontent']      = 'Įkeltas turinys neatitinka %s failo išplėtimo.';
$lang['uploadspam']            = 'Įkėlimas blokuotas pagal šiukšlintojų juodajį šąrašą.';
$lang['uploadxss']             = 'Įkėlimas blokuotas greičiausiai dėl netinkamo teksto.';
$lang['uploadsize']            = 'Įkeltas failas per didelis (maks. %s)';
$lang['deletesucc']            = 'Byla "%s" ištrinta.';
$lang['deletefail']            = 'Byla "%s" negali būti ištrinta - patikrinkite leidimus.';
$lang['mediainuse']            = 'Byla "%s" nebuvo ištrinta - ji vis dar naudojama.';
$lang['namespaces']            = 'Pavadinimai';
$lang['mediafiles']            = 'Prieinamos bylos';
$lang['js']['keepopen']        = 'Pažymėjus palikti langą atvertą';
$lang['js']['hidedetails']     = 'Paslėpti Detales';
$lang['js']['nosmblinks']      = 'Nurodos į "Windows shares" veikia tik su Microsoft Internet Explorer naršykle.
Vis dėlto, jūs galite nukopijuoti šią nuorodą.';
$lang['mediausage']            = 'Failo nuorodai užrašyti naudokite tokią sintaksę:';
$lang['mediaview']             = 'Žiūrėti pirminį failą';
$lang['mediaroot']             = 'pradžia (root)';
$lang['mediaextchange']        = 'Failo galūnė pasikeitė iš .%s į .%s!';
$lang['reference']             = 'Paminėjimai';
$lang['ref_inuse']             = 'Byla negali būti ištrinta, nes ji vis dar yra naudojama šiuose puslapiuose:';
$lang['ref_hidden']            = 'Kai kurie paminėjimai yra puslapiuose, kurių jums neleista skaityti.';
$lang['hits']                  = 'Atidarymai';
$lang['quickhits']             = 'Sutampantys pavadinimai';
$lang['toc']                   = 'Turinys';
$lang['current']               = 'esamas';
$lang['yours']                 = 'Jūsų versija';
$lang['diff']                  = 'rodyti skirtumus tarp šios ir esamos versijos';
$lang['diff2']                 = 'Parodyti skirtumus tarp pasirinktų versijų';
$lang['line']                  = 'Linija';
$lang['breadcrumb']            = 'Kelias';
$lang['youarehere']            = 'Jūs esate čia';
$lang['lastmod']               = 'Keista';
$lang['by']                    = 'vartotojo';
$lang['deleted']               = 'ištrintas';
$lang['created']               = 'sukurtas';
$lang['restored']              = 'atstatyta sena versija (%s)';
$lang['external_edit']         = 'redaguoti papildomomis priemonėmis';
$lang['summary']               = 'Redaguoti santrauką';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> reikalingas šios medžiagos peržiūrai.';
$lang['mail_newpage']          = '[DokuWiki] puslapis pridėtas:';
$lang['mail_changed']          = '[DokuWiki] puslapis pakeistas:';
$lang['mail_new_user']         = 'naujas vartotojas:';
$lang['mail_upload']           = 'failas įkeltas:';
$lang['qb_bold']               = 'Pusjuodis';
$lang['qb_italic']             = 'Kursyvas';
$lang['qb_underl']             = 'Pabrauktas';
$lang['qb_code']               = 'Kodas';
$lang['qb_strike']             = 'Perbraukta';
$lang['qb_h1']                 = 'Pirmo lygio antraštė';
$lang['qb_h2']                 = 'Antro lygio antraštė';
$lang['qb_h3']                 = 'Trečio lygio antraštė';
$lang['qb_h4']                 = 'Ketvirto lygio antraštė';
$lang['qb_h5']                 = 'Penkto lygio antraštė';
$lang['qb_link']               = 'Vidinė nuoroda';
$lang['qb_extlink']            = 'Išorinė nuoroda';
$lang['qb_hr']                 = 'Horizontali linija';
$lang['qb_ol']                 = 'Numeruotas sąrašas';
$lang['qb_ul']                 = 'Nenumetuotas sąrašas';
$lang['qb_media']              = 'Paveikslėliai ir kitos bylos';
$lang['qb_sig']                = 'Įterpti parašą';
$lang['qb_smileys']            = 'Šypsenėlės';
$lang['qb_chars']              = 'Specialūs simboliai';
$lang['js']['del_confirm']           = 'Ar tikrai ištrinti pažymėtą(us) įrašą(us)?';
$lang['admin_register']        = 'Sukurti naują vartotoją';
$lang['metaedit']              = 'Redaguoti metaduomenis';
$lang['metasaveerr']           = 'Nepavyko išsaugoti metaduomenų';
$lang['metasaveok']            = 'Metaduomenys išsaugoti';
$lang['img_backto']            = 'Atgal į';
$lang['img_title']             = 'Pavadinimas';
$lang['img_caption']           = 'Antraštė';
$lang['img_date']              = 'Data';
$lang['img_fname']             = 'Bylos pavadinimas';
$lang['img_fsize']             = 'Dydis';
$lang['img_artist']            = 'Fotografas';
$lang['img_copyr']             = 'Autorinės teisės';
$lang['img_format']            = 'Formatas';
$lang['img_camera']            = 'Kamera';
$lang['img_keywords']          = 'Raktiniai žodžiai';
$lang['authtempfail']          = 'Vartotojo tapatumo nustatymas laikinai nepasiekiamas. Jei ši situacija kartojasi, tai praneškite savo administratoriui.';
$lang['i_chooselang']          = 'Pasirinkite kalbą';
$lang['i_installer']           = 'DokuWiki Instaliatorius';
$lang['i_wikiname']            = 'Wiki vardas';
$lang['i_enableacl']           = 'Įjungti ACL (rekomenduojama)';
$lang['i_superuser']           = 'Supervartotojas';
$lang['i_problems']            = 'Instaliavimo metu buvo klaidų, kurios pateiktos žemiau. Tęsti negalima, kol nebus pašalintos priežastys.';

==> dokuwiki-2015.08.10a.tgz: dokuwiki/inc/lang/lt/lang.php <==
<?php

/**
 * @license    GPL 2 (http://www.gnu.org/licenses/gpl.html)
 * 
 * @author Linas Valiukas <shirshegsm@gmail.com>
 * @author Edmondas Girkantas <eg@zemaitija.net>
 * @author Arūnas Vaitekūnas <aras@fan.lt>
 * @author audrius.klevas@gmail.com
 * @author Tomas Darius Davainis <tomasdd@gmail.com>
 */
$lang['encoding']              = 'utf-8';
$lang['direction']             = 'ltr';
$lang['doublequoteopening']    = '„';
$lang['doublequoteclosing']    = '“';
$lang['singlequoteopening']    = '‚';
$lang['singlequoteclosing']    = '‘';
$lang['apostrophe']            = '’';
$lang['btn_edit']              = 'Redaguoti šį puslapį';
$lang['btn_source']            = 'Parodyti puslapio kodą';
$lang['btn_show']              = 'Parodyti puslapį';
$lang['btn_create']            = 'Sukurti šį puslapį';
$lang['btn_search']            = 'Paieška';
$lang['btn_save']              = 'Išsaugoti';
$lang['btn_preview']           = 'Peržiūra';
$lang['btn_top']               = 'Į viršų';
$lang['btn_newer']             = '<< naujesnė';
$lang['btn_older']             = 'senesnė >>';
$lang['btn_revs']              = 'Senos versijos';
$lang['btn_recent']            = 'Naujausi keitimai';
$lang['btn_upload']            = 'Atsiųsti bylą';
$lang['btn_cancel']            = 'Atšaukti';
$lang['btn_index']             = 'Indeksas';
$lang['btn_secedit']           = 'Redaguoti';
$lang['btn_login']             = 'Prisijungti';
$lang['btn_logout']            = 'Atsijungti';
$lang['btn_admin']             = 'Administracija';
$lang['btn_update']            = 'Atnaujinti';
$lang['btn_delete']            = 'Ištrinti';
$lang['btn_back']              = 'Atgal';
$lang['btn_backlink']          = 'Atgalinės nuorodos';
$lang['btn_subscribe']         = 'Užsisakyti keitimų prenumeratą';
$lang['btn_profile']           = 'Atnaujinti profilį';
$lang['btn_reset']             = 'Atstata';
$lang['btn_draft']             = 'Redaguoti juodraštį';
$lang['btn_recover']           = 'Atkurti juodraštį';
$lang['btn_draftdel']          = 'Šalinti juodraštį';
$lang['btn_register']          = 'Registruotis';
$lang['btn_img_backto']        = 'Atgal į %s';
$lang['loggedinas']            = 'Prisijungęs kaip:';
$lang['user']                  = 'Vartotojo vardas';
$lang['pass']                  = 'Slaptažodis';
$lang['newpass']               = 'Naujas slaptažodis';
$lang['oldpass']               = 'Patvirtinti esamą slaptažodį';
$lang['passchk']               = 'dar kartą';
$lang['remember']              = 'Prisiminti mane';
$lang['fullname']              = 'Visas vardas';
$lang['email']                 = 'El. pašto adresas';
$lang['profile']               = 'Vartotojo profilis';
$lang['badlogin']              = 'Nurodėte blogą vartotojo vardą arba slaptažodį.';
$lang['minoredit']             = 'Nedidelis pataisymas';
$lang['draftdate']             = 'Juodraštis automatiškai išsaugotas';
$lang['nosecedit']             = 'Puslapis buvo kažkieno pataisytas, teksto dalies informacija tapo pasenusi, todėl pakrautas visas puslapis.';
$lang['searchcreatepage']      = 'Jeigu neradote to, ko ieškojote, galite sukurti naują puslapį šiuo pavadinimu paspausdami "Redaguoti šį puslapį".';
$lang['regmissing']            = 'Turite užpildyti visus laukus.';
$lang['reguexists']            = 'Vartotojas su pasirinktu prisijungimo vardu jau egzistuoja.';
$lang['regsuccess']            = 'Vartotojas sukurtas, slaptažodis išsiųstas el. paštu.';
$lang['regsuccess2']           = 'Vartotojas sukurtas.';
$lang['regmailfail']           = 'Siunčiant slaptažodį el. paštu įvyko klaida - susisiekite su administracija!';
$lang['regbadmail']            = 'Nurodytas el. pašto adresas yra neteisingas - jei manote, kad tai klaida, susisiekite su administracija';
$lang['regbadpass']            = 'Įvesti slaptažodžiai nesutampa, bandykite dar kartą.';
$lang['regpwmail']             = 'Jūsų DokuWiki slaptažodis';
$lang['reghere']               = 'Dar neužsiregistravote? Padarykite tai dabar';
$lang['profna']                = 'Ši vikisvetainė neleidžia pakeisti profilio';
$lang['profnochange']          = 'Nėra pakeitimų, todėl nėra ką atlikti.';
$lang['profnoempty']           = 'Tuščias vardo arba el. pašto adreso laukas nėra leidžiamas.';
$lang['profchanged']           = 'Vartotojo profilis sėkmingai atnaujintas.';
$lang['pwdforget']             = 'Pamiršote slaptažodį? Gaukite naują';
$lang['resendna']              = 'Ši vikisvetainė neleidžia persiųsti slaptažodžių.';
$lang['resendpwdmissing']      = 'Jūs turite užpildyti visus laukus.';
$lang['resendpwdnouser']       = 'Tokio vartotojo nėra duomenų bazėje.';
$lang['resendpwdbadauth']      = 'Atsiprašome, bet šis tapatybės nustatymo kodas netinkamas. Įsitikinkite, kad panaudojote pilną patvirtinimo nuorodą.';
$lang['resendpwdconfirm']      = 'Patvirtinimo nuoroda išsiųsta el. paštu.';
$lang['resendpwdsuccess']      = 'Jūsų naujas slaptažodis buvo išsiųstas el. paštu.';
$lang['license']               = 'Jei nenurodyta kitaip, šio wiki turinys ginamas tokia licencija:';
$lang['licenseok']             = 'Pastaba: Redaguodami šį puslapį jūs sutinkate jog jūsų turinys atitinka licencijavima pagal šią licenciją';
$lang['txt_upload']            = 'Išsirinkite atsiunčiamą bylą:';
$lang['txt_filename']          = 'Įveskite wikivardą (nebūtina):';
$lang['txt_overwrt']           = 'Perrašyti egzistuojančią bylą';
$lang['lockedby']              = 'Užrakintas vartotojo:';
$lang['lockexpire']            = 'Užraktas bus nuimtas:';
$lang['js']['willexpire']      = 'Šio puslapio redagavimo užrakto galiojimo laikas baigsis po minutės.\nNorėdami išvengti nesklandumų naudokite peržiūros mygtuką ir užraktas atsinaujins.';
$lang['js']['notsavedyet']     = 'Pakeitimai nebus išsaugoti.\nTikrai tęsti?';
$lang['js']['keepopen']        = 'Pažymėjus palikti langą atvertą';
$lang['js']['hidedetails']     = 'Paslėpti Detales';
$lang['js']['nosmblinks']      = 'Nurodos į "Windows shares" veikia tik su Microsoft Internet Explorer naršykle.
Vis dėlto, jūs galite nukopijuoti šią nuorodą.';
$lang['js']['del_confirm']     = 'Ar tikrai ištrinti pažymėtą(us) įrašą(us)?';
$lang['rssfailed']             = 'Siunčiant šį feed\'ą įvyko klaida: ';
$lang['nothingfound']          = 'Paieškos rezultatų nėra.';
$lang['mediaselect']           = 'Mediabylos išsirinkimas';
$lang['uploadsucc']            = 'Atsiuntimas pavyko';
$lang['uploadfail']            = 'Atsiuntimas nepavyko. Blogi priėjimo leidimai??';
$lang['uploadwrong']           = 'Atsiuntimas atmestas. Bylos tipas neleistinas';
$lang['uploadexist']           = 'Tokia byla jau egzistuoja. Veiksmai atšaukti.';
$lang['uploadbadcontent']      = 'Įkeltas turinys neatitinka %s failo išplėtimo.';
$lang['uploadspam']            = 'Įkėlimas blokuotas pagal šiukšlintojų juodajį šąrašą.';
$lang['uploadxss']             = 'Įkėlimas blokuotas greičiausiai dėl netinkamo teksto.';
$lang['uploadsize']            = 'Įkeltas failas per didelis (maks. %s)';
$lang['deletesucc']            = 'Byla "%s" ištrinta.';
$lang['deletefail']            = 'Byla "%s" negali būti ištrinta - patikrinkite leidimus.';
$lang['mediainuse']            = 'Byla "%s" nebuvo ištrinta - ji vis dar naudojama.';
$lang['namespaces']            = 'Pavadinimai';
$lang['mediafiles']            = 'Prieinamos bylos';
$lang['mediausage']            = 'Failo nuorodai užrašyti naudokite tokią sintaksę:';
$lang['mediaview']             = 'Žiūrėti pirminį failą';
$lang['mediaroot']             = 'pradžia (root)';
$lang['mediaextchange']        = 'Failo galūnė pasikeitė iš .%s į .%s!';
$lang['reference']             = 'Paminėjimai';
$lang['ref_inuse']             = 'Byla negali būti ištrinta, nes ji vis dar yra naudojama šiuose puslapiuose:';
$lang['ref_hidden']            = 'Kai kurie paminėjimai yra puslapiuose, kurių jums neleista skaityti.';
$lang['hits']                  = 'Atidarymai';
$lang['quickhits']             = 'Sutampantys pavadinimai';
$lang['toc']                   = 'Turinys';
$lang['current']               = 'esamas';
$lang['yours']                 = 'Jūsų versija';
$lang['diff']                  = 'rodyti skirtumus tarp šios ir esamos versijos';
$lang['diff2']                 = 'Parodyti skirtumus tarp pasirinktų versijų';
$lang['line']                  = 'Linija';
$lang['breadcrumb']            = 'Kelias:';
$lang['youarehere']            = 'Jūs esate čia:';
$lang['lastmod']               = 'Keista:';
$lang['by']                    = 'vartotojo';
$lang['deleted']               = 'ištrintas';
$lang['created']               = 'sukurtas';
$lang['restored']              = 'atstatyta sena versija (%s)';
$lang['external_edit']         = 'redaguoti papildomomis priemonėmis';
$lang['summary']               = 'Redaguoti santrauką';
$lang['noflash']               = '<a href="http://www.adobe.com/products/flashplayer/">Adobe Flash Plugin</a> reikalingas šios medžiagos peržiūrai.';
$lang['mail_newpage']          = '[DokuWiki] puslapis pridėtas:';
$lang['mail_changed']          = '[DokuWiki] puslapis pakeistas:';
$lang['mail_new_user']         = 'naujas vartotojas:';
$lang['mail_upload']           = 'failas įkeltas:';
$lang['qb_bold']               = 'Pusjuodis';
$lang['qb_italic']             = 'Kursyvas';
$lang['qb_underl']             = 'Pabrauktas';
$lang['qb_code']               = 'Kodas';
$lang['qb_strike']             = 'Perbraukta';
$lang['qb_h1']                 = 'Pirmo lygio antraštė';
$lang['qb_h2']                 = 'Antro lygio antraštė';
$lang['qb_h3']                 = 'Trečio lygio antraštė';
$lang['qb_h4']                 = 'Ketvirto lygio antraštė';
$lang['qb_h5']                 = 'Penkto lygio antraštė';
$lang['qb_link']               = 'Vidinė nuoroda';
$lang['qb_extlink']            = 'Išorinė nuoroda';
$lang['qb_hr']                 = 'Horizontali linija';
$lang['qb_ol']                 = 'Numeruotas sąrašas';
$lang['qb_ul']                 = 'Nenumetuotas sąrašas';
$lang['qb_media']              = 'Paveikslėliai ir kitos bylos';
$lang['qb_sig']                = 'Įterpti parašą';
$lang['qb_smileys']            = 'Šypsenėlės';
$lang['qb_chars']              = 'Specialūs simboliai';
$lang['metaedit']              = 'Redaguoti metaduomenis';
$lang['metasaveerr']           = 'Nepavyko išsaugoti metaduomenų';
$lang['metasaveok']            = 'Metaduomenys išsaugoti';
$lang['img_title']             = 'Pavadinimas:';
$lang['img_caption']           = 'Antraštė:';
$lang['img_date']              = 'Data:';
$lang['img_fname']             = 'Bylos pavadinimas:';
$lang['img_fsize']             = 'Dydis:';
$lang['img_artist']            = 'Fotografas:';
$lang['img_copyr']             = 'Autorinės teisės:';
$lang['img_format']            = 'Formatas:';
$lang['img_camera']            = 'Kamera:';
$lang['img_keywords']          = 'Raktiniai žodžiai:';
$lang['authtempfail']          = 'Vartotojo tapatumo nustatymas laikinai nepasiekiamas. Jei ši situacija kartojasi, tai praneškite savo administratoriui.';
$lang['i_chooselang']          = 'Pasirinkite kalbą';
$lang['i_installer']           = 'DokuWiki Instaliatorius';
$lang['i_wikiname']            = 'Wiki vardas';
$lang['i_enableacl']           = 'Įjungti ACL (rekomenduojama)';
$lang['i_superuser']           = 'Supervartotojas';
$lang['i_problems']            = 'Instaliavimo metu buvo klaidų, kurios pateiktos žemiau. Tęsti negalima, kol nebus pašalintos priežastys.';
